@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-sub.h,v 1.6 2005/10/09 14:17:52 mmj Exp $
+ * $Id: mlmmj-sub.h,v 1.9 2006/09/03 17:59:07 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -26,6 +26,11 @@
 
 #include <mlmmj.h>
 
+void moderate_sub(const char *listdir, const char *listaddr,
+		  const char *listdelim, const char *subaddr,
+		  const char *mlmmjsend, enum subtype typesub);
+void getaddrandtype(const char *listdir, const char *modstr,
+		char **addrptr, enum subtype *subtypeptr);
 void confirm_sub(const char *listdir, const char *listaddr,
 		 const char *listdelim, const char *subaddr,
 		 const char *mlmmjsend, enum subtype typesub);
