@@ -1,6 +1,6 @@
 /* Copyright (C) 2002, 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: incindexfile.c,v 1.9 2005/01/13 19:30:44 mmj Exp $
+ * $Id: incindexfile.c,v 1.10 2005/05/02 17:39:10 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -66,7 +66,7 @@ int incindexfile(const char *listdir)
 		return 0;
 	}
 
-	read(fd, intbuf, INTBUF_SIZE);
+	readn(fd, intbuf, INTBUF_SIZE);
 	for(i=0; i<sizeof(intbuf); i++) {
 		if(intbuf[i] < '0' || intbuf[i] > '9') {
 			intbuf[i] = '\0';
