@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Morten K. Poulsen <morten at afdelingp.dk>
  *
- * $Id: mlmmj-bounce.c,v 1.40 2006/01/17 11:47:06 mmj Exp $
+ * $Id: mlmmj-bounce.c,v 1.41 2006/08/06 08:36:47 xi Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -139,7 +139,7 @@ void do_probe(const char *listdir, const char *mlmmjsend, const char *addr)
 
 	maildata[1] = indexstr;
 	queuefilename = prepstdreply(listdir, "bounce-probe", "$listowner$",
-					myaddr, NULL, 1, maildata);
+					myaddr, NULL, 1, maildata, NULL);
 	MY_ASSERT(queuefilename);
 	myfree(indexstr);
 
