@@ -1,6 +1,6 @@
 /* Copyright (C) 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-maintd.c,v 1.56 2006/01/04 19:39:02 mmj Exp $
+ * $Id: mlmmj-maintd.c,v 1.59 2006/11/14 13:15:54 xi Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -233,11 +233,14 @@ int resend_queue(const char *listdir, const char *mlmmjsend)
 
 		if(stat(mailname, &st) < 0) {
 			log_error(LOG_ARGS, "Could not stat(%s)", mailname);
+			myfree(mailname);
 			continue;
 		}
 
-		if(!S_ISREG(st.st_mode))
+		if(!S_ISREG(st.st_mode)) {
+			myfree(mailname);
 			continue;
+		}
 
 		if(strchr(dp->d_name, '.')) {
 			ch = strrchr(mailname, '.');
@@ -309,6 +312,7 @@ int resend_queue(const char *listdir, const char *mlmmjsend)
 		t = time(NULL);
 		if(t - st.st_mtime > bouncelife) {
 			unlink(mailname);
+			myfree(mailname);
 			continue;
 		}
 
@@ -367,7 +371,7 @@ int resend_requeue(const char *listdir, const char *mlmmjsend)
 	struct stat st;
 	pid_t childpid, pid;
 	time_t t;
-	int status;
+	int status, fromrequeuedir = 0;
 
 	if(chdir(dirname) < 0) {
 		log_error(LOG_ARGS, "Could not chdir(%s)", dirname);
@@ -408,10 +412,22 @@ int resend_requeue(const char *listdir, const char *mlmmjsend)
 			 * continue
 			 */
 			myfree(archivefilename);
-			continue;
+
+			/* If the list is set not to archive we want to look
+			 * in /requeue/ for a mailfile
+			 */
+			archivefilename = concatstr(4, listdir, "/requeue/",
+							dp->d_name, "/mailfile");
+			if(stat(archivefilename, &st) < 0) {
+				myfree(archivefilename);
+				continue;
+			}
+			fromrequeuedir = 1;
 		}
 		subfilename = concatstr(3, dirname, dp->d_name, "/subscribers");
 		if(stat(subfilename, &st) < 0) {
+			if (fromrequeuedir)
+				unlink(archivefilename);
 			myfree(archivefilename);
 			myfree(subfilename);
 			continue;
@@ -745,12 +761,12 @@ int unsub_bouncers(const char *listdir, const char *mlmmjunsub)
 
 int run_digests(const char *listdir, const char *mlmmjsend)
 {
-	char *lasttimestr, *lastindexstr;
+	char *lasttimestr, *lastindexstr, *lastissuestr;
 	char *digestname, *indexname;
 	char *digestintervalstr, *digestmaxmailsstr;
 	char *s1, *s2, *s3;
 	time_t digestinterval, t, lasttime;
-	long digestmaxmails, lastindex, index;
+	long digestmaxmails, lastindex, index, lastissue;
 	int fd, indexfd, lock;
 	size_t lenbuf, lenstr;
 	
@@ -788,9 +804,15 @@ int run_digests(const char *listdir, const char *mlmmjsend)
 
 	s1 = mygetline(fd);
 
-	/* Syntax is lastindex:lasttime */
+	/* Syntax is lastindex:lasttime or lastindex:lasttime:lastissue */
 	if (s1 && (lasttimestr = strchr(s1, ':'))) {
 		*(lasttimestr++) = '\0';
+		if ((lastissuestr = strchr(lasttimestr, ':'))) {
+			*(lastissuestr++) = '\0';
+			lastissue = atol(lastissuestr);
+		} else {
+			lastissue = 0;
+		}
 		lasttime = atol(lasttimestr);
 		lastindexstr = s1;
 		lastindex = atol(lastindexstr);
@@ -806,6 +828,7 @@ int run_digests(const char *listdir, const char *mlmmjsend)
 		/* If lastdigest is empty, we start from scratch */
 		lasttime = 0;
 		lastindex = 0;
+		lastissue = 0;
 	}
 	
 	indexname = concatstr(2, listdir, "/index");
@@ -839,15 +862,18 @@ int run_digests(const char *listdir, const char *mlmmjsend)
 		if (index > lastindex+digestmaxmails)
 			index = lastindex+digestmaxmails;
 
-		send_digest(listdir, lastindex+1, index, NULL, mlmmjsend);
+		if (index > lastindex) {
+			lastissue++;
+			send_digest(listdir, lastindex+1, index, lastissue, NULL, mlmmjsend);
+		}
 
 		if (lseek(fd, 0, SEEK_SET) < 0) {
 			log_error(LOG_ARGS, "Could not seek '%s'", digestname);
 		} else {
-			/* index + ':' + time + '\n' + '\0' */
-			lenbuf = 20 + 1 + 20 + 2;
+			/* index + ':' + time + ':' + issue + '\n' + '\0' */
+			lenbuf = 20 + 1 + 20 + 1 + 20 + 2;
 			s3 = mymalloc(lenbuf);
-			lenstr = snprintf(s3, lenbuf, "%ld:%ld\n", index, (long)t);
+			lenstr = snprintf(s3, lenbuf, "%ld:%ld:%ld\n", index, (long)t, lastissue);
 			if (lenstr >= lenbuf)
 				lenstr = lenbuf - 1;
 			if (writen(fd, s3, lenstr) == -1) {
