@@ -1,6 +1,6 @@
 /* Copyright (C) 2003, 2003, 2004 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: mlmmj-process.c,v 1.80 2006/12/04 17:24:27 mmj Exp $
+ * $Id: mlmmj-process.c,v 1.83 2007/05/09 16:59:23 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -56,15 +56,16 @@
 enum action {
 	ALLOW,
 	DENY,
-	MODERATE
+	MODERATE,
+	DISCARD
 };
 
 
-struct rule_list {
-	regex_t regexp;
-	unsigned int not;
-	enum action act;
-	struct rule_list *next;
+static char *action_strs[] = {
+	"allowed",
+	"denied",
+	"moderated",
+	"discarded"
 };
 
 
@@ -154,147 +155,133 @@ void newmoderated(const char *listdir, const char *mailfilename,
 }
 
 
-static void free_rules(struct rule_list *rule)
+static enum action do_access(struct strlist *rule_strs, struct strlist *hdrs,
+		const char *from, const char *listdir)
 {
-	struct rule_list *next;
-
-	while (rule) {
-		next = rule->next;
-		regfree(&rule->regexp);
-		myfree(rule);
-		rule = next;
-	}
-}
-
-
-static enum action do_access(struct strlist *rule_strs, struct strlist *hdrs)
-{
-	int i;
+	int i, j;
 	unsigned int match;
-	unsigned int rule_nr;
-	struct rule_list *head = NULL;
-	struct rule_list *rule, *new_rule;
 	char *rule_ptr;
 	char errbuf[128];
 	int err;
-	enum action ret;
+	enum action act;
+	unsigned int not;
+	regex_t regexp;
+	char *hdr;
 
-	/* They're going in backwards later on, so loop from the end here
-	 * to get it right
-	 */
-	for (i=rule_strs->count-1; i>=0; i--) {
-		new_rule = mymalloc(sizeof(struct rule_list));
-
-		/* linked list */
-		new_rule->next = head;
-		head = new_rule;
+	for (i=0; i<rule_strs->count; i++) {
 
 		rule_ptr = rule_strs->strs[i];
+
 		if (strncmp(rule_ptr, "allow", 5) == 0) {
 			rule_ptr += 5;
-			new_rule->act = ALLOW;
+			act = ALLOW;
 		} else if (strncmp(rule_ptr, "deny", 4) == 0) {
 			rule_ptr += 4;
-			new_rule->act = DENY;
+			act = DENY;
 		} else if (strncmp(rule_ptr, "moderate", 8) == 0) {
 			rule_ptr += 8;
-			new_rule->act = MODERATE;
+			act = MODERATE;
+		} else if (strncmp(rule_ptr, "discard", 7) == 0) {
+			rule_ptr += 7;
+			act = DISCARD;
 		} else {
 			errno = 0;
-			log_error(LOG_ARGS, "Unable to parse rule #%d!"
-					" Denying post to list", i);
-			free_rules(head);
+			log_error(LOG_ARGS, "Unable to parse rule #%d \"%s\":"
+					" Missing action keyword. Denying post from \"%s\"",
+					i, rule_strs->strs[i], from);
+			log_oper(listdir, OPLOGFNAME, "Unable to parse rule #%d \"%s\":"
+					" Missing action keyword. Denying post from \"%s\"",
+					i, rule_strs->strs[i], from);
 			return DENY;
 		}
 
 		if (*rule_ptr == ' ') {
 			rule_ptr++;
 		} else if (*rule_ptr == '\0') {
-			/* We had a single allow/deny so match everything */
-			*(--rule_ptr) = '.';
+			/* the rule is a keyword and no regexp */
+			log_oper(listdir, OPLOGFNAME, "mlmmj-process: access -"
+					" A mail from \"%s\" was %s by rule #%d \"%s\"",
+					from, action_strs[act], i, rule_strs->strs[i]);
+			return act;
 		} else {
 			/* we must have space or end of string */
 			errno = 0;
-			log_error(LOG_ARGS, "Unable to parse rule #%d!"
-					" Denying post to list", i);
-			free_rules(head);
+			log_error(LOG_ARGS, "Unable to parse rule #%d \"%s\":"
+					" Invalid character after action keyword."
+					" Denying post from \"%s\"", i, rule_strs->strs[i], from);
+			log_oper(listdir, OPLOGFNAME, "Unable to parse rule #%d \"%s\":"
+					" Invalid character after action keyword."
+					" Denying post from \"%s\"", i, rule_strs->strs[i], from);
 			return DENY;
 		}
 
 		if (*rule_ptr == '!') {
 			rule_ptr++;
-			new_rule->not = 1;
+			not = 1;
 		} else {
-			new_rule->not = 0;
+			not = 0;
 		}
 
 		/* remove unanchored ".*" from beginning of regexp to stop the
 		 * regexp matching to loop so long time it seems like it's
 		 * hanging */
-		
-		if (strlen(rule_ptr) > 2 && !strncmp(rule_ptr, ".*", 2))
-			memmove(rule_ptr, rule_ptr + 2, strlen(rule_ptr) - 1);
+		if (strncmp(rule_ptr, "^.*", 3) == 0) {
+			rule_ptr += 3;
+		}
+		while (strncmp(rule_ptr, ".*", 2) == 0) {
+			rule_ptr += 2;
+		}
 
-		if ((err = regcomp(&new_rule->regexp, rule_ptr,
+		if ((err = regcomp(&regexp, rule_ptr,
 				REG_EXTENDED | REG_NOSUB | REG_ICASE))) {
-			regerror(err, &new_rule->regexp, errbuf,
-					sizeof(errbuf));
+			regerror(err, &regexp, errbuf, sizeof(errbuf));
+			regfree(&regexp);
 			errno = 0;
-			log_error(LOG_ARGS, "regcomp() failed for rule #%d!"
+			log_error(LOG_ARGS, "regcomp() failed for rule #%d \"%s\""
 					" (message: '%s') (expression: '%s')"
-					" Denying post to list",
-					i, errbuf, rule_ptr);
-			free_rules(head);
+					" Denying post from \"%s\"",
+					i, rule_strs->strs[i], errbuf, rule_ptr, from);
+			log_oper(listdir, OPLOGFNAME, "regcomp() failed for rule"
+					" #%d \"%s\" (message: '%s') (expression: '%s')"
+					" Denying post from \"%s\"",
+					i, rule_strs->strs[i], errbuf, rule_ptr, from);
 			return DENY;
 		}
-		
-#if 0
-		printf("rule #%d: %s if%s match '%s'\n", i,
-				(new_rule->act == ALLOW) ? "allow" : "deny",
-				(new_rule->not) ? " not" : "",
-				rule_ptr);
-#endif
 
-	}
-
-	rule = head;
-	for (rule_nr=0; rule; rule_nr++) {
 		match = 0;
-		for (i=0; i<hdrs->count; i++) {
-			if (regexec(&rule->regexp, hdrs->strs[i], 0, NULL, 0)
+		for (j=0; j<hdrs->count; j++) {
+			if (regexec(&regexp, hdrs->strs[j], 0, NULL, 0)
 					== 0) {
 				match = 1;
 				break;
 			}
 		}
-		if (match != rule->not) {
-			char *logstr;
 
-			errno = 0;
-			switch(rule->act) {
-				case ALLOW:
-					logstr = "allowed";
-					break;
-				case MODERATE:
-					logstr = "moderated";
-					break;
-				default:
-				case DENY:
-					logstr = "denied";
-					break;
+		regfree(&regexp);
+		
+		if (match != not) {
+			if (match) {
+				hdr = mystrdup(hdrs->strs[j]);
+				chomp(hdr);
+				log_oper(listdir, OPLOGFNAME, "mlmmj-process: access -"
+						" A mail from \"%s\" with header \"%s\" was %s by"
+						" rule #%d \"%s\"", from, hdr, action_strs[act],
+						i, rule_strs->strs[i]);
+				myfree(hdr);
+			} else {
+				log_oper(listdir, OPLOGFNAME, "mlmmj-process: access -"
+						" A mail from \"%s\" was %s by rule #%d \"%s\""
+						" because no header matched.", from,
+						action_strs[act], i, rule_strs->strs[i]);
 			}
-
-			log_error(LOG_ARGS, "A mail was %s by rule #%d",
-					logstr, rule_nr);
-			ret = rule->act;
-			free_rules(head);
-			return ret;
+			return act;
 		}
 
-		rule = rule->next;
 	}
 
-	free_rules(head);
+	log_oper(listdir, OPLOGFNAME, "mlmmj-process: access -"
+			" A mail from \"%s\" didn't match any rules, and"
+			" was denied by default.", from);
 	return DENY;
 }
 
@@ -348,7 +335,9 @@ int main(int argc, char **argv)
 	int i, j, opt, noprocess = 0, moderated = 0;
 	int hdrfd, footfd, rawmailfd, donemailfd;
 	int subonlypost = 0, addrtocc = 1, intocc = 0, modnonsubposts = 0;
+	int maxmailsize = 0;
 	int notoccdenymails = 0, noaccessdenymails = 0, nosubonlydenymails = 0;
+	int nomaxmailsizedenymails = 0;
 	char *listdir = NULL, *mailfile = NULL, *headerfilename = NULL;
 	char *footerfilename = NULL, *donemailname = NULL;
 	char *randomstr = NULL, *mqueuename;
@@ -356,7 +345,8 @@ int main(int argc, char **argv)
 	char *bindir, *subjectprefix, *discardname, *listaddr, *listdelim;
 	char *listfqdn, *listname, *fromaddr;
 	char *queuefilename, *recipextra = NULL, *owner = NULL;
-	char *maildata[2] = { "posteraddr", NULL };
+	char *maxmailsizestr;
+	char *maildata[4] = { "posteraddr", NULL, "maxmailsize", NULL };
 	char *envstr, *efrom;
 	struct stat st;
 	uid_t uid;
@@ -631,6 +621,63 @@ int main(int argc, char **argv)
 		return EXIT_SUCCESS;
 	}
 
+	listaddr = getlistaddr(listdir);
+	alternates = ctrlvalues(listdir, "listaddress");
+	
+	/* checking incoming mail's size */
+	maxmailsizestr = ctrlvalue(listdir, "maxmailsize");
+	if(maxmailsizestr) {
+		maxmailsize = atol(maxmailsizestr);
+		if(stat(donemailname, &st) < 0) {
+			log_error(LOG_ARGS, "stat(%s,..) failed", donemailname);
+			exit(EXIT_FAILURE);
+		}
+
+		if(st.st_size > maxmailsize) {
+
+			nomaxmailsizedenymails = statctrl(listdir, "nomaxmailsizedenymails");
+			if (nomaxmailsizedenymails) {
+				errno = 0;
+				log_error(LOG_ARGS, "Discarding %s due to"
+						" size limit (%d bytes too big)",
+						donemailname, (st.st_size - maxmailsize));
+				unlink(donemailname);
+				unlink(mailfile);
+				myfree(donemailname);
+				myfree(maxmailsizestr);
+				exit(EXIT_SUCCESS);
+			}
+
+			listdelim = getlistdelim(listdir);
+			listname = genlistname(listaddr);
+			listfqdn = genlistfqdn(listaddr);
+			fromaddr = concatstr(4, listname, listdelim,
+					"bounces-help@", listfqdn);
+			maildata[3] = maxmailsizestr;
+			queuefilename = prepstdreply(listdir,
+					"maxmailsize", "$listowner$",
+					fromemails.emaillist[0],
+					NULL, 2, maildata, NULL);
+			MY_ASSERT(queuefilename)
+			myfree(listdelim);
+			myfree(listname);
+			myfree(listfqdn);
+			unlink(donemailname);
+			unlink(mailfile);
+			myfree(donemailname);
+			myfree(maxmailsizestr);
+			execlp(mlmmjsend, mlmmjsend,
+					"-l", "1",
+					"-L", listdir,
+					"-T", fromemails.emaillist[0],
+					"-F", fromaddr,
+					"-m", queuefilename, (char *)NULL);
+		
+			log_error(LOG_ARGS, "execlp() of '%s' failed", mlmmjsend);
+			exit(EXIT_FAILURE);
+		}
+	}
+
 	/* discard malformed mail with invalid From: */
 	if(fromemails.emailcount != 1) { 
 		for(i = 0; i < fromemails.emailcount; i++)
@@ -673,9 +720,6 @@ int main(int argc, char **argv)
 
 	unlink(mailfile);
 
-	listaddr = getlistaddr(listdir);
-	alternates = ctrlvalues(listdir, "listaddress");
-
 	addrtocc = !(statctrl(listdir, "tocc"));
 	if(addrtocc) {
 		for(i = 0; i < toemails.emailcount; i++) {
@@ -812,7 +856,8 @@ startaccess:
 		enum action accret;
 		/* Don't send a mail about denial to the list, but silently
 		 * discard and exit. Also do this in case it's turned off */
-		accret = do_access(access_rules, &allheaders);
+		accret = do_access(access_rules, &allheaders,
+								fromemails.emaillist[0], listdir);
 		if (accret == DENY) {
 			if ((strcasecmp(listaddr, fromemails.emaillist[0]) ==
 						0) || noaccessdenymails) {
@@ -856,6 +901,20 @@ startaccess:
 			exit(EXIT_FAILURE);
 		} else if (accret == MODERATE) {
 			moderated = 1;
+		} else if (accret == DISCARD) {
+	                discardname = concatstr(3, listdir,
+                                "/queue/discarded/", randomstr);
+			myfree(randomstr);
+                	if(rename(donemailname, discardname) < 0) {
+				log_error(LOG_ARGS, "could not rename(%s,%s)",
+					    donemailname, discardname);
+				myfree(donemailname);
+				myfree(discardname);
+				exit(EXIT_FAILURE);
+			}
+			myfree(donemailname);
+			myfree(discardname);
+                	exit(EXIT_SUCCESS);
 		}
 	}
 	
