@@ -1,6 +1,6 @@
 /* Copyright (C) 2004, 2005 Morten K. Poulsen <morten at afdelingp.dk>
  *
- * $Id: send_digest.c,v 1.11 2006/09/03 21:49:01 mortenp Exp $
+ * $Id: send_digest.c,v 1.13 2007/06/13 20:54:41 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -44,6 +44,7 @@
 #include "gethdrline.h"
 #include "statctrl.h"
 #include "unistr.h"
+#include "chomp.h"
 
 
 struct mail {
@@ -182,6 +183,7 @@ int send_digest(const char *listdir, int firstindex, int lastindex,
 	int i, fd, archivefd, status, hdrfd, txtfd;
 	char buf[45];
 	char *tmp, *queuename = NULL, *archivename, *subject, *line = NULL;
+	char *utfsub, *utfsub2, *utfline;
 	char *boundary, *listaddr, *listdelim, *listname, *listfqdn;
 	char *subst_data[10];
 	pid_t childpid, pid;
@@ -222,9 +224,7 @@ int send_digest(const char *listdir, int firstindex, int lastindex,
 	listfqdn = genlistfqdn(listaddr);
 	listdelim = getlistdelim(listdir);
 	
-	tmp = concatstr(2, listdir, "/text/digest");
-	txtfd = open(tmp, O_RDONLY);
-	myfree(tmp);
+	txtfd = open_listtext(listdir, "digest");
 	if (txtfd < 0) {
 		log_error(LOG_ARGS, "Notice: Could not open std mail digest");
 	}
@@ -252,22 +252,28 @@ int send_digest(const char *listdir, int firstindex, int lastindex,
 	subst_data[8] = "digestthreads";
 	subst_data[9] = thread_list(listdir, firstindex, lastindex);
 
-	if ((txtfd > 0) && (line = mygetline(txtfd)) &&
-			(strncasecmp(line, "Subject: ", 9) == 0)) {
-		subject = substitute(line + 9, listaddr, listdelim,
-				5, subst_data);
+	if ((txtfd < 0) || !(line = mygetline(txtfd)) ||
+			(strncasecmp(line, "Subject: ", 9) != 0)) {
+
+		utfsub = mystrdup("Digest of $listaddr$ issue $digestissue$"
+				" ($digestinterval$)");
 	} else {
-		subject = substitute("Digest of $listaddr$ issue $digestissue$"
-				" ($digestinterval$)\n", listaddr, listdelim,
-				5, subst_data);
+
+		chomp(line);
+		utfsub = unistr_escaped_to_utf8(line + 9);
 	}
 
-	tmp = concatstr(9, "From: ", listname, listdelim, "help@", listfqdn,
+	utfsub2 = substitute(utfsub, listaddr, listdelim, 5, subst_data);
+	subject = unistr_utf8_to_header(utfsub2);
+	myfree(utfsub);
+	myfree(utfsub2);
+
+	tmp = concatstr(10, "From: ", listname, listdelim, "help@", listfqdn,
 			   "\nMIME-Version: 1.0"
 			   "\nContent-Type: multipart/" DIGESTMIMETYPE "; "
 			   "boundary=", boundary,
-			   "\nSubject: ", subject);
-	/* subject includes a newline */
+			   "\nSubject: ", subject,
+			   "\n");
 
 	myfree(listfqdn);
 	myfree(subject);
@@ -313,8 +319,9 @@ errdighdrs:
 
 	if ((txtfd > 0) && !statctrl(listdir, "nodigesttext")) {
 
-		tmp = concatstr(3, "--", boundary,
+		tmp = concatstr(3, "\n--", boundary,
 				"\nContent-Type: text/plain; charset=UTF-8"
+				"\nContent-Encoding: 8bit"
 				"\n\n");
 		if (writen(fd, tmp, strlen(tmp)) == -1) {
 			log_error(LOG_ARGS, "Could not write digest text/plain"
@@ -351,9 +358,13 @@ errdighdrs:
 
 		if (line) {
 			do {
-				tmp = substitute(line, listaddr, listdelim,
-						5, subst_data);
+				utfline = unistr_escaped_to_utf8(line);
 				myfree(line);
+
+				tmp = substitute(utfline, listaddr, listdelim,
+						5, subst_data);
+				myfree(utfline);
+
 				if(writen(fd, tmp, strlen(tmp)) < 0) {
 					myfree(tmp);
 					log_error(LOG_ARGS, "Could not write"
@@ -386,7 +397,7 @@ errdighdrs:
 		if (archivefd < 0)
 			continue;
 		
-		tmp = concatstr(7, "--", boundary,
+		tmp = concatstr(7, "\n--", boundary,
 				"\nContent-Type: message/rfc822"
 				"\nContent-Disposition: inline; filename=\"",
 					listname, "_", buf, ".eml\""
@@ -422,7 +433,7 @@ errdighdrs:
 		close(archivefd);
 	}
 
-	tmp = concatstr(3, "--", boundary, "--\n");
+	tmp = concatstr(3, "\n--", boundary, "--\n");
 	if (writen(fd, tmp, strlen(tmp)) == -1) {
 		log_error(LOG_ARGS, "Could not write digest end to '%s'",
 				queuename);
