@@ -1,6 +1,6 @@
 /* Copyright (C) 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: send_help.c,v 1.19 2006/01/04 19:39:02 mmj Exp $
+ * $Id: send_help.c,v 1.21 2006/12/06 21:29:27 mortenp Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -43,7 +43,7 @@
 #include "memory.h"
 
 void send_help(const char *listdir, const char *emailaddr,
-	       const char *mlmmjsend)
+	       const char *mlmmjsend, const char *name, const char *textfile)
 {
 	char *queuefilename, *listaddr, *listdelim, *listname, *listfqdn;
 	char *fromaddr;
@@ -56,10 +56,10 @@ void send_help(const char *listdir, const char *emailaddr,
 	fromaddr = concatstr(4, listname, listdelim, "bounces-help@", listfqdn);
 	myfree(listdelim);
 
-	queuefilename = prepstdreply(listdir, "listhelp", "$listowner$",
-					emailaddr, NULL, 0, NULL);
+	queuefilename = prepstdreply(listdir, textfile, "$listowner$",
+					emailaddr, NULL, 0, NULL, NULL);
 	if(queuefilename == NULL) {
-		log_error(LOG_ARGS, "Could not prepare help mail");
+		log_error(LOG_ARGS, "Could not prepare %s mail", name);
 		exit(EXIT_FAILURE);
 	}
 	
