@@ -1,6 +1,6 @@
 /* Copyright (C) 2005 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: send_list.c,v 1.5 2006/01/04 19:39:02 mmj Exp $
+ * $Id: send_list.c,v 1.6 2006/08/06 08:36:48 xi Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -61,7 +61,7 @@ void send_list(const char *listdir, const char *emailaddr,
 	myfree(listdelim);
 
 	queuefilename = prepstdreply(listdir, "listsubs", "$listowner$",
-					emailaddr, NULL, 0, NULL);
+					emailaddr, NULL, 0, NULL, NULL);
 	if(queuefilename == NULL) {
 		log_error(LOG_ARGS, "Could not prepare sub list mail");
 		exit(EXIT_FAILURE);
