@@ -1,6 +1,6 @@
 /* Copyright (C) 2003 Mads Martin Joergensen <mmj at mmj.dk>
  *
- * $Id: subscriberfuncs.c,v 1.15 2005/02/14 22:56:45 mmj Exp $
+ * $Id: subscriberfuncs.c,v 1.16 2006/04/10 20:40:39 mmj Exp $
  *
  * Permission is hereby granted, free of charge, to any person obtaining a copy
  * of this software and associated documentation files (the "Software"), to
@@ -51,6 +51,10 @@ off_t find_subscriber(int fd, const char *address)
 		return (off_t)-1;
 	}
 
+	/* No need to check in 0-size file */
+	if(st.st_size == 0)
+		return (off_t)-1;
+
 	if(!S_ISREG(st.st_mode)) {
 		log_error(LOG_ARGS, "Non regular file in subscribers.d/");
 		return (off_t)-1;
